@@ -161,7 +161,12 @@ class DomainGroupProps:
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-dns.DomainProps",
     jsii_struct_bases=[],
-    name_mapping={"domain_name": "domainName", "group_id": "groupId", "tags": "tags"},
+    name_mapping={
+        "domain_name": "domainName",
+        "group_id": "groupId",
+        "resource_group_id": "resourceGroupId",
+        "tags": "tags",
+    },
 )
 class DomainProps:
     def __init__(
@@ -169,12 +174,14 @@ class DomainProps:
         *,
         domain_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         tags: typing.Optional[typing.Sequence["RosDomain.TagsProperty"]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::DNS::Domain``.
 
         :param domain_name: Property domainName: Domain name.
         :param group_id: Property groupId: Domain name grouping, the default is the "default grouping" GroupId.
+        :param resource_group_id: Property resourceGroupId: Resource group id.
         :param tags: Property tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
         '''
         self._values: typing.Dict[str, typing.Any] = {
@@ -182,6 +189,8 @@ class DomainProps:
         }
         if group_id is not None:
             self._values["group_id"] = group_id
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
         if tags is not None:
             self._values["tags"] = tags
 
@@ -200,6 +209,14 @@ class DomainProps:
         result = self._values.get("group_id")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property resourceGroupId: Resource group id.'''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["RosDomain.TagsProperty"]]:
         '''Property tags: Tags to attach to instance.
@@ -506,6 +523,23 @@ class RosDomain(
     ) -> None:
         jsii.set(self, "groupId", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resourceGroupId")
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "resourceGroupId"))
+
+    @resource_group_id.setter
+    def resource_group_id(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "resourceGroupId", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="tags")
     def tags(self) -> typing.Optional[typing.List["RosDomain.TagsProperty"]]:
@@ -694,7 +728,12 @@ class RosDomainGroupProps:
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-dns.RosDomainProps",
     jsii_struct_bases=[],
-    name_mapping={"domain_name": "domainName", "group_id": "groupId", "tags": "tags"},
+    name_mapping={
+        "domain_name": "domainName",
+        "group_id": "groupId",
+        "resource_group_id": "resourceGroupId",
+        "tags": "tags",
+    },
 )
 class RosDomainProps:
     def __init__(
@@ -702,12 +741,14 @@ class RosDomainProps:
         *,
         domain_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         tags: typing.Optional[typing.Sequence[RosDomain.TagsProperty]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::DNS::Domain``.
 
         :param domain_name: 
         :param group_id: 
+        :param resource_group_id: 
         :param tags: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
@@ -715,6 +756,8 @@ class RosDomainProps:
         }
         if group_id is not None:
             self._values["group_id"] = group_id
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
         if tags is not None:
             self._values["tags"] = tags
 
@@ -737,6 +780,16 @@ class RosDomainProps:
         result = self._values.get("group_id")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[RosDomain.TagsProperty]]:
         '''
